# orquestra-python-dev
This is a meta-package collecting all development libraries needed in other, Python-based, 
Orquestra packages. The tools which this package tracks versions of are:

- black
- flake8
- isort
- mypy
- pytest
- pytest-cov
